# Sayvai-Tools

## How to use 
---------------------------------------

## Installation
### Install via git clone

```bash
$git clone https://github.com/Sayvai-io/custom-tools.git
$cd sayvai-tools
```
and 
```bash
$pip install .
```
### Install via pip
```bash
$pip install sayvai-tools
```
### Install via pipenv
```bash
$pipenv install sayvai-tools
```

## What is Sayvai-Tools?
---------------------------------------
Sayvai-Tools is a collection of tools that we use at Sayvai.io to help us build our products. We are making these tools available to the public in hopes that they will help you build your products as well. These tools are meant for langchain developers and are not meant to be used by end users.

# Documentation
---------------------------------------
Documentation is available at https://sayvai-io.github.io/custom-tools/


1. [Sayvai-Tools](#sayvai-tools)
2. [How to use](#how-to-use)
3. [What is Sayvai-Tools?](#what-is-sayvai-tools)
4. [Documentation](#documentation)
5. [Installation](#installation)
    1. [Install via git clone](#install-via-git-clone)
    2. [Install via pip](#install-via-pip)
    3. [Install via pipenv](#install-via-pipenv)

